@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 import inspect
-from typing import List
+from typing import List, Optional
 
+from .models import UserStatusEnum, AccountServiceException
 from .grpc_client import AccountServiceGRPCClient
 from .models import UserPagination, User
 
@@ -41,6 +42,14 @@ def get_user_list(id_list: list) -> List[User]:
 
 
 @_param_check
-def get_user_page_list(current_page: int = 1, page_size: int = 10, username: str = '',
-                       phone: str = '', email: str = '', name: str = '') -> UserPagination:
-    return _client.get_user_page_list(current_page, page_size, username, phone, email, name)
+def get_user_page_list(current_page: int = 1, page_size: int = 10, username: str = '', phone: str = '', email: str = '',
+                       name: str = '', user_status_list: Optional[List] = None) -> UserPagination:
+    if user_status_list is not None:
+        validate_user_status_list(user_status_list)
+    return _client.get_user_page_list(current_page, page_size, username, phone, email, name, user_status_list)
+
+
+def validate_user_status_list(user_status_list: list):
+    """判断user_status_list是否合法"""
+    if not set(user_status_list).issubset(set(UserStatusEnum.value_list())):
+        raise AccountServiceException('user_status_list参数不合法')
